==> localuserdb-0.4.2.tar.gz: localuserdb-0.4.2/README.md <==
# LocalUserDB

This is a simple python package which just uses a local txt file to store user info for your python code..

# Functions

 - `createUser()`
    Takes only 3 Arguments - "username(unique for every user), FullName(can be same for different users.) & e-mail"

 - `findUser()`
    Takes only 1 argument - "username(as it is unique for every user.)"

 - `deleteUser()`
    Takes only 1 argument - "username(as it is unique for every user.)"

 - `verifyUser()`
    Takes only 3 arguments - "username, sender's mail(google), sender's mail-password(google)"
     - this feature verifies the user using an otp function.. which will be sent to the mail registered to the account when creating it.

 - `editUsername()`
    Takes only 2 arguments - "currentUsername, newUsername"

 - `editMail()`
    Takes only 2 arguments - "currentMail, newMail"


# How To Use

I advise you to use a virtual environment of python and then use this package as this package makes a `customers.txt` file in the directory the package source files are.. so if you make a virtual enironment(venv), then it would be easy for you developers to access that `customers.txt` file in your local directory.

# How To Make A Virual Environment (venv)

 - In Python 3, you just have to run the command `python -m venv [name-of-your-venv]` and it will create a venv in the local directory you are in.
 - After making a venv, you have to activate it and to do that, you'll have to run another command which is `.\[name-of-your-venv]\Scripts\activate`
 - After you activate the venv, you just have to install this package using pip as you normally do with the command `pip install localuserdb` or in some systems `python -m pip install localuserdb`
 - After the installation, you'll be able to import and use it in your project and also you'll find the `customers.txt` file in the `lib/site-packages/localuserdb` folder in your `venv folder`.

# For Future

Features like user credentials editing will be added and examples about how to use this package will be made public on my github - (`https://github.com/akshprooo`)

==> localuserdb-0.5.tar.gz: localuserdb-0.5/README.md <==
# LocalUserDB

This is a simple python package which just uses a local txt file to store user info for your python code..

# Functions

 - `createUser()`
    Takes only 4 Arguments - "username(unique for every user), FullName(can be same for different users.), e-mail & password"

 - `findUser()`
    Takes only 1 argument - "username(as it is unique for every user.)"

 - `deleteUser()`
    Takes only 2 argument - "username(as it is unique for every user.) & password"

 - `verifyUser()`
    Takes only 3 arguments - "username, sender's mail(google), sender's mail-password(google)"
     - this feature verifies the user using an otp function.. which will be sent to the mail registered to the account when creating it.

 - `editUsername()`
    Takes only 3 arguments - "currentUsername, newUsername, password"

 - `editMail()`
    Takes only 3 arguments - "currentMail, newMail, password"

 - `getUserInfo()`
    Takes 1 argument, "the username".. this function takes the username and prints the info of the user like - "email, full name etc."

 - `getRawData()`
    This is an Admin Function which prints the file in raw format, eg. all files as it is.
   
 - `clearDB()`
    As The name says, this function clears the database(the text file).


# How To Use

I advise you to use a virtual environment of python and then use this package as this package makes a `customers.txt` file in the directory the package source files are.. so if you make a virtual enironment(venv), then it would be easy for you developers to access that `customers.txt` file in your local directory.

## How To Make A Virual Environment (venv)

 - In Python 3, you just have to run the command `python -m venv [name-of-your-venv]` and it will create a venv in the local directory you are in.
 - After making a venv, you have to activate it and to do that, you'll have to run another command which is `.\[name-of-your-venv]\Scripts\activate`
 - After you activate the venv, you just have to install this package using pip as you normally do with the command `pip install localuserdb` or in some systems `python -m pip install localuserdb`
 - After the installation, you'll be able to import and use it in your project and also you'll find the `customers.txt` file in the `lib/site-packages/localuserdb` folder in your `venv folder`.

# For Future

 - Future Plans are to implement some encrytion algorithms and also functions to help database admins, eg. encryptData() and decryptData().. while making sure the database is well protected from digital attacks or data breaches.
